@@ -10,6 +10,8 @@ import sys
 import requests
 import websocket
 
+from psclient import chatlog
+
 ranksInOrder = list("+%☆@★*#&~")
 LOGLEVEL = 1
 
@@ -81,6 +83,7 @@ class Room():
         """Joins the room
         """
         self.connection.send(f'|/j {self.id}')
+        self.connection.roomList.add(self)
         self.say(f'/cmd roominfo {self.id}')
 
     def usersWithRankGEQ(self, rank):
@@ -133,7 +136,7 @@ class User():
             [bool] -- True if the user can do the action and False otherwise
         """
         if not room: return False
-        if action not in ['wall', 'html']: self.connection.log(f"E: User.can(): {action} isn't a valid action")
+        if action not in ['wall', 'html']: log(f"E: User.can(): {action} isn't a valid action")
         return (
             (action == 'wall' and self.id in room.usersWithRankGEQ('%')) or
             (action == 'html' and self.id in room.usersWithRankGEQ('*'))
@@ -186,7 +189,7 @@ class Message():
         elif self.type == 'pm': self._handlePM(split)
         elif self.type == 'queryresponse': self._handleQuery(split)
         elif self.type == 'init': pass
-        else: self.connection.log(f"DEBUG: Message() of unknown type {self.type}: {self.raw}")
+        else: log(f"DEBUG: Message() of unknown type {self.type}: {self.raw}")
 
     def respondHTML(self, html):
         """Responds to the message with a HTML box, in a room or in PMs
@@ -200,10 +203,10 @@ class Message():
             return self.room.say(f"/adduhtml {self.connection.this.userid},{html}")
         if self.sender and not self.room:
             possibleRoomIDs = [r for r in self.connection.getUserRooms(self.sender) \
-                if r in self.connection.getUserRooms(self.connection.bot)]
+                if r in self.connection.getUserRooms(self.connection.this)]
             for possibleRoom in possibleRoomIDs:
                 possibleRoom = self.connection.getRoom(possibleRoom)
-                if possibleRoom and self.connection.bot.can("html", possibleRoom):
+                if possibleRoom and self.connection.this.can("html", possibleRoom):
                     return possibleRoom.say(f"/pminfobox {self.sender.id}," + html.replace('\n', ''))
 
     def _handleChat(self, split):
@@ -358,13 +361,13 @@ class PSConnection():
         Arguments:
             challstr {string} -- the challstr to use to log in
         """
-        self.log("I: PSConnection.login(): logging in...")
+        log("I: PSConnection.login(): logging in...")
         loginInfo = {'act': 'login', 'name': self.this.name, 'pass': self.password, 'challstr': challstr}
         loginResponse = requests.post('http://play.pokemonshowdown.com/action.php', data=loginInfo).content
         assertion = json.loads(loginResponse[1:].decode('utf-8'))['assertion']
         self.send(f"|/trn {self.this.name},0,{assertion}")
         self.isLoggedIn = True
-        return self.log("I: PSConnection.login(): logged in successfully")
+        return log("I: PSConnection.login(): logged in successfully")
 
     def send(self, message):
         """Sends a message
@@ -391,7 +394,7 @@ class PSConnection():
         objects = [room for room in self.roomList if room.id == roomid]
         if len(objects) == 0: return None
         if len(objects) > 1:
-            self.log(f"W: PSConnection.getRoom(): more than 1 Room object for room {roomid}")
+            log(f"W: PSConnection.getRoom(): more than 1 Room object for room {roomid}")
         return objects[0]
 
     def getUser(self, userid):
@@ -475,17 +478,17 @@ class PSConnection():
         Arguments:
             error {string? probably} -- the error
         """
-        self.log(f"E: PSConnection.onError(): websocket error: {error}")
+        log(f"E: PSConnection.onError(): websocket error: {error}")
 
     def onClose(self):
         """Logs when the connection closes
         """
-        self.log("I: PSConnection.onClose(): websocket closed")
+        log("I: PSConnection.onClose(): websocket closed")
 
     def onOpen(self):
         """Logs when the websocket is opened
         """
-        self.log("I: PSConnection.onOpen(): websocket successfully opened")
+        log("I: PSConnection.onOpen(): websocket successfully opened")
         if self.onOpenThread:
             thread = threading.Thread(target=self.onOpenThread, args=tuple([self]))
             thread.start()
@@ -499,7 +502,7 @@ class PSConnection():
         if self.chatlogger: self.chatlogger.handleMessage(message)
         if message.challstr:
             self.login(message.challstr)
-        if self.onParsedMessage: self.onParsedMessage(message)
+        if self.onParsedMessage: self.onParsedMessage(self, message)
 
     def __str__(self):
         """String representation of the PSConnection
